@@ -21,7 +21,7 @@ all_hosts <- c(
   "https://xena.treehouse.gi.ucsc.edu",
   "https://pcawg.xenahubs.net",
   "https://atacseq.xenahubs.net",
-  "https://singlecell.xenahubs.net"
+  "https://singlecellnew.xenahubs.net"
 )
 
 
